==> dataone.common-3.3.0-py3-none-any.whl: d1_common/logging_context.py <==
# -*- coding: utf-8 -*-

# This work was created by participants in the DataONE project, and is
# jointly copyrighted by participating institutions in DataONE. For
# more information on DataONE, see our web site at http://dataone.org.
#
#   Copyright 2009-2017 DataONE
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""Context manager that enables temporary changes in logging level.

Source: https://docs.python.org/2/howto/logging-cookbook.html
"""


class LoggingContext(object):
    """Logging Context Manager."""

    def __init__(self, logger, level=None, handler=None, close=True):
        """
    Args:
      logger: logger
        Logger for which to change the logging level.

      level:
        Temporary logging level.

      handler:
        Optional logging handler to use. Supplying a new handler allows temporarily
        changing the logging format as well.

      close:
        Automatically close handler (if supplied).
    """
        self.logger = logger
        self.level = level
        self.handler = handler
        self.close = close

    def __enter__(self):
        if self.level is not None:
            self.old_level = self.logger.level
            self.logger.setLevel(self.level)
        if self.handler:
            self.logger.addHandler(self.handler)

    def __exit__(self, et, ev, tb):
        if self.level is not None:
            self.logger.setLevel(self.old_level)
        if self.handler:
            self.logger.removeHandler(self.handler)
        if self.handler and self.close:
            self.handler.close()
            # implicit return of None => don't swallow exceptions

==> dataone.common-3.4.3-py3-none-any.whl: d1_common/logging_context.py <==
# This work was created by participants in the DataONE project, and is
# jointly copyrighted by participating institutions in DataONE. For
# more information on DataONE, see our web site at http://dataone.org.
#
#   Copyright 2009-2017 DataONE
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""Context manager that enables temporary changes in logging level.

Source: https://docs.python.org/2/howto/logging-cookbook.html

"""


class LoggingContext(object):
    """Logging Context Manager."""

    def __init__(self, logger, level=None, handler=None, close=True):
        """Args: logger: logger Logger for which to change the logging level.

        level:
          Temporary logging level.

        handler:
          Optional logging handler to use. Supplying a new handler allows temporarily
          changing the logging format as well.

        close:
          Automatically close handler (if supplied).

        """
        self.logger = logger
        self.level = level
        self.handler = handler
        self.close = close

    def __enter__(self):
        if self.level is not None:
            self.old_level = self.logger.level
            self.logger.setLevel(self.level)
        if self.handler:
            self.logger.addHandler(self.handler)

    def __exit__(self, et, ev, tb):
        if self.level is not None:
            self.logger.setLevel(self.old_level)
        if self.handler:
            self.logger.removeHandler(self.handler)
        if self.handler and self.close:
            self.handler.close()
            # implicit return of None => don't swallow exceptions
